@@ -122,6 +122,9 @@ def _cache_data(data_type: str,
         else:
             value = data[key]
         if type(key) in (np.ndarray, tuple):
+            if type(key) != tuple:
+                key[0] = datetime.fromtimestamp(key[0].timestamp())
+                key[1] = datetime.fromtimestamp(key[1].timestamp())
             file_name = (f"{key[0].strftime(DATE_YMD_TIME_HM).replace(':', '-')} - "
                          f"{key[1].strftime(DATE_YMD_TIME_HM).replace(':', '-')}")
             year_month = key[0].strftime("%Y-%m")
